# yaqd-core-python

[![PyPI](https://img.shields.io/pypi/v/yaqd-core)](https://pypi.org/project/yaqd-core)
[![Conda](https://img.shields.io/conda/vn/conda-forge/yaqd-core)](https://anaconda.org/conda-forge/yaqd-core)
[![black](https://img.shields.io/badge/code--style-black-black)](https://black.readthedocs.io/)
[![ver](https://img.shields.io/badge/calver-YYYY.0M.MICRO-blue)](https://calver.org/)
[![log](https://img.shields.io/badge/change-log-informational)](https://gitlab.com/yaq/yaqd-core-python/-/blob/master/CHANGELOG.md)

Core python package for implementing yaq daemons, and associated utilities.

Documentation at https://yaqd-core-python.yaq.fyi

